@@ -12,7 +12,7 @@ impl Handler for MaxSizeHandler {
     async fn handle(&self, req: &mut Request, depot: &mut Depot, res: &mut Response, ctrl: &mut FlowCtrl) {
         if let Some(upper) = req.body().and_then(|body| body.size_hint().upper()) {
             if upper > self.0 {
-                res.set_http_error(PayloadTooLarge());
+                res.set_status_error(PayloadTooLarge());
                 ctrl.skip_reset();
             } else {
                 ctrl.call_next(req, depot, res).await;
